WITH eo_rank_class_cnt
AS (
	SELECT es_id
		,rank_class
		,COUNT(rank_class) class_cnt
	FROM (
		SELECT element_subnational_id es_id
			,eo_id
			,CASE 
				WHEN d_basic_eo_rank_id < 9
					THEN 'good'
				WHEN d_basic_eo_rank_id < 15
					THEN 'poor'
				ELSE 'bad'
				END AS rank_class
		FROM eo
		ORDER BY es_id
		)
	GROUP BY es_id
		,rank_class
	ORDER BY es_id
	)
SELECT eg.elcode_bcd AS elcode
    ,sn_g.scientific_name AS gname
    ,eg.g_primary_common_name AS gcomname
    ,cnts.sf_cnt AS sf_cnt_all
    ,cnts.eo_cnt_all
    ,cnts.eo_cnt_extant
	,rcc_good.class_cnt AS good
	,rcc_poor.class_cnt AS poor
	,rcc_bad.class_cnt AS bad
FROM element_subnational es
LEFT JOIN (SELECT es_id, class_cnt from eo_rank_class_cnt rcc_good WHERE rank_class = 'good') rcc_good ON rcc_good.es_id = es.element_subnational_id
LEFT JOIN (SELECT es_id, class_cnt from eo_rank_class_cnt rcc_poor WHERE rank_class = 'poor') rcc_poor ON rcc_poor.es_id = es.element_subnational_id
LEFT JOIN (SELECT es_id, class_cnt from eo_rank_class_cnt rcc_bad WHERE rank_class = 'bad') rcc_bad ON rcc_bad.es_id = es.element_subnational_id
LEFT JOIN (
SELECT s.es_id
	,sf_cnt
	,eo_cnt_all
    ,CASE 
        WHEN eo_cnt_extant IS NOT NULL
            THEN eo_cnt_extant
        ELSE 0
    END AS eo_cnt_extant
FROM (
	SELECT COUNT(source_feature_id) sf_cnt
		,element_subnational_id es_id
	FROM source_feature
	GROUP BY element_subnational_id
	) s
LEFT JOIN (
	SELECT COUNT(EO_ID) eo_cnt_all
		,element_subnational_id es_id
	FROM eo
	GROUP BY element_subnational_id
	) o ON s.es_id = o.es_id
LEFT JOIN (
	SELECT COUNT(EO_ID) eo_cnt_extant
		,element_subnational_id es_id
	FROM eo
        LEFT JOIN d_basic_eo_rank eorank ON eorank.d_basic_eo_rank_id = eo.d_basic_eo_rank_id
    -- filter out eorank H, X and lastobs older than 1980, include eorank nulls
    WHERE (eorank.basic_eo_rank_cd NOT IN ('H', 'X') 
        OR eorank.basic_eo_rank_cd IS NULL) 
        AND SubStr(last_obs_date, 1 ,4) > '1979'
	GROUP BY element_subnational_id
	) e ON s.es_id = e.es_id) cnts ON cnts.es_id = es.element_subnational_id
LEFT JOIN element_national en on es.element_national_id = en.element_national_id
LEFT JOIN element_global eg ON eg.element_global_id = en.element_global_id
LEFT JOIN scientific_name sn_g ON sn_g.scientific_name_id = eg.gname_id
LEFT JOIN scientific_name sn_s ON sn_s.scientific_name_id = es.sname_id
WHERE es.d_eo_track_status_id = 1
AND SUBSTR(eg.elcode_bcd, 1, 1) IN ('P', 'N', 'A', 'I')
ORDER BY sn_g.scientific_name
